@@ -36,7 +36,8 @@ from .site import (
     RequestRevisionsAs,
 )
 from .file import TrackedFile, Revision
-from .kitsu import KitsuAPIWrapper
+from .kitsu import KitsuAPIWrapper, KitsuBindings
+from .dependency import DependencyTemplates
 
 
 class LoginPageWidget(CustomPageWidget):
@@ -242,6 +243,7 @@ class KitsuConfig(flow.Object):
     gazu_api = flow.Child(KitsuAPIWrapper).ui(
         hidden=True
     )
+    bindings = flow.Child(KitsuBindings)
 
     def child_value_changed(self, child_value):
         self.project_id.touch()
@@ -344,6 +346,8 @@ class Admin(flow.Object):
     settings = flow.Child(ContextualView)
     users = flow.Child(Users)
     kitsu = flow.Child(KitsuConfig)
+
+    dependency_templates = flow.Child(DependencyTemplates)
     
     user_environment = flow.Child(UserEnvironment).ui(expanded=False)
     default_applications = flow.Child(DefaultRunners).ui(expanded=False).injectable()
@@ -519,6 +523,10 @@ class Project(flow.Object):
     def kitsu_api(self):
         return self.admin.kitsu.gazu_api
 
+    def kitsu_bindings(self):
+        return self.admin.kitsu.bindings
+
+
     def get_contextual_view(self, context_name):
         if context_name == "settings":
             return self.admin.settings
