@@ -56,15 +56,15 @@ class RevisionsChoiceValue(flow.values.ChoiceValue):
         return self._file.get_revisions().mapped_names()
 
     def revert_to_default(self):
-        name = self._file.current_user_sees.get()
-        if name == "current":
-            if not self._file.has_current_revision():
-                revisions = self._file.get_revisions().mapped_items()
-                name = revisions[0].name()
-            else:
-                name = self._file.current_revision.get()
+        if self._file.is_empty():
+            self.set("")
 
-        self.set(name)
+        revision = self._file.get_head_revision()
+        
+        if revision is None:
+            revision = self._file.get_working_copy()
+        
+        self.set(revision.name())
 
 
 class CreateWorkingCopyFromRevision(CreateWorkingCopyBaseAction):
@@ -118,6 +118,16 @@ class OpenRevision(RunAction):
     def needs_dialog(self):
         return False
     
+    def extra_env(self):
+        env = get_contextual_dict(self, "settings")
+        env["USER_NAME"] = self.root().project().get_user()
+        root_path = self.root().project().get_root()
+
+        if root_path:
+            env["ROOT_PATH"] = root_path
+
+        return env
+    
     def extra_argv(self):
         return [self._revision.get_path()]
     
@@ -766,9 +776,7 @@ class OpenTrackedFileAction(GenericRunAction):
         if user_sees == "current":
             if not self._file.has_current_revision():
                 msg = "<h3>No active revision</h3>"
-                # msg += "You aren't seeing any revision. Choose a revision to open, or create a working copy to edit."
                 self.message.set(msg)
-                self.revision_name.set(self._file.get_revisions().mapped_names()[0])
 
                 return buttons
 
@@ -776,7 +784,6 @@ class OpenTrackedFileAction(GenericRunAction):
 
         # Current user is seeing a revision
         revision = self._file.get_revision(user_sees)
-        self.revision_name.set(user_sees)
 
         if not revision.is_working_copy(from_current_user=True):
             msg = "<h3>Read-only mode</h3>"
@@ -1088,6 +1095,10 @@ class RenderBlenderPlayblastAction(OpenWithBlenderAction):
 
     _files = flow.Parent(2)
     revision_name = flow.Param("", RevisionsChoiceValue).watched()
+    use_simplify = flow.SessionParam(False).ui(
+        tooltip="Use low-definition rigs",
+        editor='bool',
+    )
 
     def _sequence_number_from_name(self, sequence_name):
         tmp = re.findall(r"\d+", sequence_name)
@@ -1151,12 +1162,14 @@ class RenderBlenderPlayblastAction(OpenWithBlenderAction):
         project_name = self.root().project().name()
         revision = self._file.get_revision(self.revision_name.get())
         python_expr = """import bpy
-bpy.ops.lfs.playblast(do_render=True, filepath='%s', studio='%s', project='%s', sequence='s%04i', scene='%s')""" % (
+bpy.ops.lfs.playblast(do_render=True, filepath='%s', studio='%s', project='%s', sequence='s%04i', scene='%s', do_simplify=%s, version='%s')""" % (
             self.output_path,
             self.root().project().get_current_site().name(),
             project_name,
             self._sequence_number_from_name(file_settings["sequence"]),
             file_settings["shot"],
+            str(self.use_simplify.get()),
+            self.revision_name.get(),
         )
 
         return [
@@ -1384,6 +1397,20 @@ class TrackedFile(File):
 
     def get_revisions(self):
         return self.history.revisions
+    
+    def get_revision_names(self, sync_status=None, published_only=False):
+        if sync_status is None and not published_only:
+            return self.get_revisions().mapped_names()
+
+        revisions = self.get_revisions().mapped_items()
+
+        if published_only:
+            revisions = filter(lambda r: not r.is_working_copy(), revisions)
+
+        if sync_status is not None:
+            revisions = filter(lambda r: r.get_sync_status() == sync_status, revisions)
+        
+        return [r.name() for r in revisions]
 
     def has_revision(self, name, sync_status=None):
         exists = (name in self.history.revisions.mapped_names())
@@ -1871,10 +1898,6 @@ class PublishIntoFile(PublishFileAction):
             comment=self.comment.get(),
         )
         target_file.unlock()
-
-        if self._department.auto_current.get():
-            publication.make_current.run(None)
-
         target_file._map.touch()
 
         if self.upload_after_publish.get():
