@@ -88,6 +88,9 @@ class KitsuAPIWrapper(flow.Object):
         if isinstance(shot, str):
             shot = self.get_shot_data(shot, sequence)
 
+        if not shot:
+            return None
+
         return gazu.casting.get_shot_casting(shot)
     
     def get_sequence_data(self, name):
@@ -100,6 +103,9 @@ class KitsuAPIWrapper(flow.Object):
         if isinstance(sequence, str):
             sequence = self.get_sequence_data(sequence)
 
+        if not sequence:
+            return None
+
         return gazu.casting.get_sequence_casting(sequence)
     
     def get_asset_data(self, name):
@@ -112,9 +118,69 @@ class KitsuAPIWrapper(flow.Object):
         if isinstance(asset, str):
             asset = self.get_asset_data(asset)
 
+        if not asset:
+            return None
+
         return gazu.asset.get_asset_type(asset["entity_type_id"])
 
 
+class KitsuBindings(flow.Object):
+
+    asset_types = flow.HashParam()
+    asset_families = flow.HashParam()
+
+    def _kitsu_api(self):
+        return self.root().project().kitsu_api()
+
+    def get_asset_oid(self, kitsu_asset_name):
+        kitsu_api = self.root().project().kitsu_api()
+        kitsu_asset = kitsu_api.get_asset_data(kitsu_asset_name)
+
+        asset_type = kitsu_api.get_asset_type(kitsu_asset['name'])['name']
+        asset_type = self.get_asset_type(asset_type)
+        asset_family = self.get_asset_family(kitsu_asset['data']['family'])
+
+        return '%s/asset_lib/asset_types/%s/asset_families/%s/assets/%s' % (
+            self.root().project().oid(),
+            asset_type,
+            asset_family,
+            kitsu_asset['name']
+        )
+
+    def get_asset_data(self, name):
+        kitsu_api = self._kitsu_api()
+        kitsu_asset = kitsu_api.get_asset_data(name)
+
+        return dict(
+            type=kitsu_api.get_asset_type(name)['name'],
+            family=kitsu_asset['data']['family']
+        )
+
+    def get_shot_casting(self, shot_name, sequence_name):
+        kitsu_api = self._kitsu_api()
+        kitsu_casting = kitsu_api.get_shot_casting(shot_name, sequence_name)
+        casting = dict()
+
+        for asset in kitsu_casting:
+            asset_name = asset['asset_name']
+            asset_data = self.get_asset_data(asset_name)
+            asset_data['nb_occurrences'] = asset['nb_occurences']
+            casting[asset_name] = asset_data
+
+        return casting
+
+    def get_asset_type(self, kitsu_asset_type):
+        if not self.asset_types.has_key(kitsu_asset_type):
+            return kitsu_asset_type
+
+        return self.asset_types.get_key(kitsu_asset_type)
+
+    def get_asset_family(self, kitsu_asset_family):
+        if not self.asset_families.has_key(kitsu_asset_family):
+            return kitsu_asset_family
+
+        return self.asset_families.get_key(kitsu_asset_family)
+
 class UpdateKitsuSettings(flow.Action):
 
     _kitsu_object = flow.Parent(2)
